BuildCommandBuilder

Struct BuildCommandBuilder 

pub struct BuildCommandBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> BuildCommandBuilder<S>

pub fn build(self) -> BuildCommand
where S: IsComplete,

Finish building and return the requested object

pub fn recipe( self, value: impl Into<Vec<PathBuf>>, ) -> BuildCommandBuilder<SetRecipe<S>>
where S::Recipe: IsUnset,

Optional (Some / Option setters). The recipe file to build an image

pub fn maybe_recipe( self, value: Option<impl Into<Vec<PathBuf>>>, ) -> BuildCommandBuilder<SetRecipe<S>>
where S::Recipe: IsUnset,

Optional (Some / Option setters). The recipe file to build an image

pub fn push(self, value: bool) -> BuildCommandBuilder<SetPush<S>>
where S::Push: IsUnset,

Optional (Some / Option setters). Default: false.

Push the image with all the tags.

Requires --registry, --username, and --password if not building in CI.

pub fn maybe_push(self, value: Option<bool>) -> BuildCommandBuilder<SetPush<S>>
where S::Push: IsUnset,

Optional (Some / Option setters). Default: false.

Push the image with all the tags.

Requires --registry, --username, and --password if not building in CI.

pub fn platform( self, value: Vec<Platform>, ) -> BuildCommandBuilder<SetPlatform<S>>
where S::Platform: IsUnset,

Optional (Some / Option setters). Default: <Vec<Platform> as Default>::default().

Build for specific platforms.

This will override any platform setting in the recipes you’re building.

NOTE: Building for a different architecture than your hardware will require installing qemu. Build times will be much greater when building for a non-native architecture.

pub fn maybe_platform( self, value: Option<Vec<Platform>>, ) -> BuildCommandBuilder<SetPlatform<S>>
where S::Platform: IsUnset,

Optional (Some / Option setters). Default: <Vec<Platform> as Default>::default().

Build for specific platforms.

This will override any platform setting in the recipes you’re building.

NOTE: Building for a different architecture than your hardware will require installing qemu. Build times will be much greater when building for a non-native architecture.

pub fn compression_format( self, value: CompressionType, ) -> BuildCommandBuilder<SetCompressionFormat<S>>
where S::CompressionFormat: IsUnset,

Optional (Some / Option setters). Default: <CompressionType as Default>::default().

The compression format the images will be pushed in.

pub fn maybe_compression_format( self, value: Option<CompressionType>, ) -> BuildCommandBuilder<SetCompressionFormat<S>>
where S::CompressionFormat: IsUnset,

Optional (Some / Option setters). Default: <CompressionType as Default>::default().

The compression format the images will be pushed in.

pub fn retry_push(self, value: bool) -> BuildCommandBuilder<SetRetryPush<S>>
where S::RetryPush: IsUnset,

Optional (Some / Option setters). Default: false.

Enable retrying to push the image.

pub fn maybe_retry_push( self, value: Option<bool>, ) -> BuildCommandBuilder<SetRetryPush<S>>
where S::RetryPush: IsUnset,

Optional (Some / Option setters). Default: false.

Enable retrying to push the image.

pub fn retry_count(self, value: u8) -> BuildCommandBuilder<SetRetryCount<S>>
where S::RetryCount: IsUnset,

Optional (Some / Option setters). Default: 0.

The number of times to retry pushing the image.

pub fn maybe_retry_count( self, value: Option<u8>, ) -> BuildCommandBuilder<SetRetryCount<S>>
where S::RetryCount: IsUnset,

Optional (Some / Option setters). Default: 0.

The number of times to retry pushing the image.

pub fn archive( self, value: impl Into<PathBuf>, ) -> BuildCommandBuilder<SetArchive<S>>
where S::Archive: IsUnset,

Optional (Some / Option setters). Archives the built image into a tarfile in the specified directory.

pub fn maybe_archive( self, value: Option<impl Into<PathBuf>>, ) -> BuildCommandBuilder<SetArchive<S>>
where S::Archive: IsUnset,

Optional (Some / Option setters). Archives the built image into a tarfile in the specified directory.

pub fn registry_namespace( self, value: impl Into<String>, ) -> BuildCommandBuilder<SetRegistryNamespace<S>>
where S::RegistryNamespace: IsUnset,

Optional (Some / Option setters). The url path to your base project images.

pub fn maybe_registry_namespace( self, value: Option<impl Into<String>>, ) -> BuildCommandBuilder<SetRegistryNamespace<S>>
where S::RegistryNamespace: IsUnset,

Optional (Some / Option setters). The url path to your base project images.

pub fn no_sign(self, value: bool) -> BuildCommandBuilder<SetNoSign<S>>
where S::NoSign: IsUnset,

Optional (Some / Option setters). Default: false.

Do not sign the image on push.

pub fn maybe_no_sign( self, value: Option<bool>, ) -> BuildCommandBuilder<SetNoSign<S>>
where S::NoSign: IsUnset,

Optional (Some / Option setters). Default: false.

Do not sign the image on push.

pub fn squash(self, value: bool) -> BuildCommandBuilder<SetSquash<S>>
where S::Squash: IsUnset,

Optional (Some / Option setters). Default: false.

Runs all instructions inside one layer of the final image.

WARN: This doesn’t work with the docker driver as it has been deprecated.

NOTE: Squash has a performance benefit for podman and buildah when running inside a container.

pub fn maybe_squash( self, value: Option<bool>, ) -> BuildCommandBuilder<SetSquash<S>>
where S::Squash: IsUnset,

Optional (Some / Option setters). Default: false.

Runs all instructions inside one layer of the final image.

WARN: This doesn’t work with the docker driver as it has been deprecated.

NOTE: Squash has a performance benefit for podman and buildah when running inside a container.

pub fn build_chunked_oci( self, value: bool, ) -> BuildCommandBuilder<SetBuildChunkedOci<S>>
where S::BuildChunkedOci: IsUnset,

Optional (Some / Option setters). Default: false.

Uses rpm-ostree compose build-chunked-oci to rechunk the image, allowing for smaller images and smaller updates.

WARN: This will increase the build-time and take up more space during build-time.

pub fn maybe_build_chunked_oci( self, value: Option<bool>, ) -> BuildCommandBuilder<SetBuildChunkedOci<S>>
where S::BuildChunkedOci: IsUnset,

Optional (Some / Option setters). Default: false.

Uses rpm-ostree compose build-chunked-oci to rechunk the image, allowing for smaller images and smaller updates.

WARN: This will increase the build-time and take up more space during build-time.

pub fn max_layers( self, value: NonZeroU32, ) -> BuildCommandBuilder<SetMaxLayers<S>>
where S::MaxLayers: IsUnset,

Optional (Some / Option setters). Default: DEFAULT_MAX_LAYERS.

Maximum number of layers to use when rechunking. Requires --build-chunked-oci.

pub fn maybe_max_layers( self, value: Option<NonZeroU32>, ) -> BuildCommandBuilder<SetMaxLayers<S>>
where S::MaxLayers: IsUnset,

Optional (Some / Option setters). Default: DEFAULT_MAX_LAYERS.

Maximum number of layers to use when rechunking. Requires --build-chunked-oci.

pub fn remove_base_image( self, value: bool, ) -> BuildCommandBuilder<SetRemoveBaseImage<S>>
where S::RemoveBaseImage: IsUnset,

Optional (Some / Option setters). Default: false.

Removes the base image from local storage and prunes unused podman containers and volumes after the image is built, but before running build-chunked-oci. This frees up additional disk space.

pub fn maybe_remove_base_image( self, value: Option<bool>, ) -> BuildCommandBuilder<SetRemoveBaseImage<S>>
where S::RemoveBaseImage: IsUnset,

Optional (Some / Option setters). Default: false.

Removes the base image from local storage and prunes unused podman containers and volumes after the image is built, but before running build-chunked-oci. This frees up additional disk space.

pub fn rechunk(self, value: bool) -> BuildCommandBuilder<SetRechunk<S>>
where S::Rechunk: IsUnset,

Optional (Some / Option setters). Default: false.

Uses hhd-dev/rechunk to rechunk the image, allowing for smaller images and smaller updates.

WARN: This will be deprecated in the future.

WARN: This will increase the build-time and take up more space during build-time.

NOTE: This must be run as root!

pub fn maybe_rechunk( self, value: Option<bool>, ) -> BuildCommandBuilder<SetRechunk<S>>
where S::Rechunk: IsUnset,

Optional (Some / Option setters). Default: false.

Uses hhd-dev/rechunk to rechunk the image, allowing for smaller images and smaller updates.

WARN: This will be deprecated in the future.

WARN: This will increase the build-time and take up more space during build-time.

NOTE: This must be run as root!

pub fn rechunk_clear_plan( self, value: bool, ) -> BuildCommandBuilder<SetRechunkClearPlan<S>>
where S::RechunkClearPlan: IsUnset,

Optional (Some / Option setters). Default: false.

Use a fresh rechunk plan, regardless of previous ref.

NOTE: Only works with --build-chunked-oci or --rechunk.

pub fn maybe_rechunk_clear_plan( self, value: Option<bool>, ) -> BuildCommandBuilder<SetRechunkClearPlan<S>>
where S::RechunkClearPlan: IsUnset,

Optional (Some / Option setters). Default: false.

Use a fresh rechunk plan, regardless of previous ref.

NOTE: Only works with --build-chunked-oci or --rechunk.

pub fn tempdir(self, value: PathBuf) -> BuildCommandBuilder<SetTempdir<S>>
where S::Tempdir: IsUnset,

Optional (Some / Option setters). The location to temporarily store files while building. If unset, it will use /tmp.

pub fn maybe_tempdir( self, value: Option<PathBuf>, ) -> BuildCommandBuilder<SetTempdir<S>>
where S::Tempdir: IsUnset,

Optional (Some / Option setters). The location to temporarily store files while building. If unset, it will use /tmp.

pub fn cache_layers(self, value: bool) -> BuildCommandBuilder<SetCacheLayers<S>>
where S::CacheLayers: IsUnset,

Optional (Some / Option setters). Default: false.

Automatically cache build layers to the registry.

NOTE: Only works when using –push

pub fn maybe_cache_layers( self, value: Option<bool>, ) -> BuildCommandBuilder<SetCacheLayers<S>>
where S::CacheLayers: IsUnset,

Optional (Some / Option setters). Default: false.

Automatically cache build layers to the registry.

NOTE: Only works when using –push

pub fn skip_validation( self, value: bool, ) -> BuildCommandBuilder<SetSkipValidation<S>>
where S::SkipValidation: IsUnset,

Optional (Some / Option setters). Default: false.

Skips validation of the recipe file.

pub fn maybe_skip_validation( self, value: Option<bool>, ) -> BuildCommandBuilder<SetSkipValidation<S>>
where S::SkipValidation: IsUnset,

Optional (Some / Option setters). Default: false.

Skips validation of the recipe file.

pub fn credentials( self, value: CredentialsArgs, ) -> BuildCommandBuilder<SetCredentials<S>>
where S::Credentials: IsUnset,

Optional (Some / Option setters). Default: <CredentialsArgs as Default>::default().

pub fn maybe_credentials( self, value: Option<CredentialsArgs>, ) -> BuildCommandBuilder<SetCredentials<S>>
where S::Credentials: IsUnset,

Optional (Some / Option setters). Default: <CredentialsArgs as Default>::default().

pub fn drivers(self, value: DriverArgs) -> BuildCommandBuilder<SetDrivers<S>>
where S::Drivers: IsUnset,

Optional (Some / Option setters). Default: <DriverArgs as Default>::default().

pub fn maybe_drivers( self, value: Option<DriverArgs>, ) -> BuildCommandBuilder<SetDrivers<S>>
where S::Drivers: IsUnset,

Optional (Some / Option setters). Default: <DriverArgs as Default>::default().