BlueBuildCommand

Trait BlueBuildCommand 

pub trait BlueBuildCommand {
    // Required method
    fn try_run(&mut self) -> Result<()>;

    // Provided method
    fn run(&mut self) { ... }
}

Required Methods

fn try_run(&mut self) -> Result<()>

Runs the command and returns a result of the execution

Errors

Can return an anyhow Error

Provided Methods

fn run(&mut self)

Runs the command and exits if there is an error.

Implementors