Struct blue_build::template::ModuleExt
source · pub struct ModuleExt {
pub modules: Vec<Module>,
}Fields
modules: Vec<Module>Trait Implementations
sourceimpl<'de> Deserialize<'de> for ModuleExt
impl<'de> Deserialize<'de> for ModuleExt
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Template for ModuleExt
impl Template for ModuleExt
sourcefn render_into(&self, writer: &mut (impl Write + ?Sized)) -> Result<()>
fn render_into(&self, writer: &mut (impl Write + ?Sized)) -> Result<()>
Renders the template to the given
writer fmt buffersourceconst SIZE_HINT: usize = 7usize
const SIZE_HINT: usize = 7usize
Provides a rough estimate of the expanded length of the rendered template. Larger
values result in higher memory usage but fewer reallocations. Smaller values result in the
opposite. This value only affects
render. It does not take effect when calling
render_into, write_into, the fmt::Display implementation, or the blanket
ToString::to_string implementation.sourceconst MIME_TYPE: &'static str = "application/octet-stream"
const MIME_TYPE: &'static str = "application/octet-stream"
The MIME type (Content-Type) of the data that gets rendered by this Template