pub struct BuildCommandBuilder<S: State = Empty> { /* private fields */ }Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> BuildCommandBuilder<S>
impl<S: State> BuildCommandBuilder<S>
Sourcepub fn build(self) -> BuildCommandwhere
S: IsComplete,
pub fn build(self) -> BuildCommandwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn recipe(
self,
value: impl Into<Vec<PathBuf>>,
) -> BuildCommandBuilder<SetRecipe<S>>where
S::Recipe: IsUnset,
pub fn recipe(
self,
value: impl Into<Vec<PathBuf>>,
) -> BuildCommandBuilder<SetRecipe<S>>where
S::Recipe: IsUnset,
Sourcepub fn maybe_recipe(
self,
value: Option<impl Into<Vec<PathBuf>>>,
) -> BuildCommandBuilder<SetRecipe<S>>where
S::Recipe: IsUnset,
pub fn maybe_recipe(
self,
value: Option<impl Into<Vec<PathBuf>>>,
) -> BuildCommandBuilder<SetRecipe<S>>where
S::Recipe: IsUnset,
Sourcepub fn push(self, value: bool) -> BuildCommandBuilder<SetPush<S>>where
S::Push: IsUnset,
pub fn push(self, value: bool) -> BuildCommandBuilder<SetPush<S>>where
S::Push: IsUnset,
Sourcepub fn maybe_push(self, value: Option<bool>) -> BuildCommandBuilder<SetPush<S>>where
S::Push: IsUnset,
pub fn maybe_push(self, value: Option<bool>) -> BuildCommandBuilder<SetPush<S>>where
S::Push: IsUnset,
Sourcepub fn platform(
self,
value: Vec<Platform>,
) -> BuildCommandBuilder<SetPlatform<S>>where
S::Platform: IsUnset,
pub fn platform(
self,
value: Vec<Platform>,
) -> BuildCommandBuilder<SetPlatform<S>>where
S::Platform: IsUnset,
Optional (Some / Option setters).
Default: <Vec<Platform> as Default>::default().
Build for specific platforms.
This will override any platform setting in the recipes you’re building.
NOTE: Building for a different architecture than your hardware will require installing qemu. Build times will be much greater when building for a non-native architecture.
Sourcepub fn maybe_platform(
self,
value: Option<Vec<Platform>>,
) -> BuildCommandBuilder<SetPlatform<S>>where
S::Platform: IsUnset,
pub fn maybe_platform(
self,
value: Option<Vec<Platform>>,
) -> BuildCommandBuilder<SetPlatform<S>>where
S::Platform: IsUnset,
Optional (Some / Option setters).
Default: <Vec<Platform> as Default>::default().
Build for specific platforms.
This will override any platform setting in the recipes you’re building.
NOTE: Building for a different architecture than your hardware will require installing qemu. Build times will be much greater when building for a non-native architecture.
Sourcepub fn compression_format(
self,
value: CompressionType,
) -> BuildCommandBuilder<SetCompressionFormat<S>>where
S::CompressionFormat: IsUnset,
pub fn compression_format(
self,
value: CompressionType,
) -> BuildCommandBuilder<SetCompressionFormat<S>>where
S::CompressionFormat: IsUnset,
Sourcepub fn maybe_compression_format(
self,
value: Option<CompressionType>,
) -> BuildCommandBuilder<SetCompressionFormat<S>>where
S::CompressionFormat: IsUnset,
pub fn maybe_compression_format(
self,
value: Option<CompressionType>,
) -> BuildCommandBuilder<SetCompressionFormat<S>>where
S::CompressionFormat: IsUnset,
Sourcepub fn retry_push(self, value: bool) -> BuildCommandBuilder<SetRetryPush<S>>where
S::RetryPush: IsUnset,
pub fn retry_push(self, value: bool) -> BuildCommandBuilder<SetRetryPush<S>>where
S::RetryPush: IsUnset,
Sourcepub fn maybe_retry_push(
self,
value: Option<bool>,
) -> BuildCommandBuilder<SetRetryPush<S>>where
S::RetryPush: IsUnset,
pub fn maybe_retry_push(
self,
value: Option<bool>,
) -> BuildCommandBuilder<SetRetryPush<S>>where
S::RetryPush: IsUnset,
Sourcepub fn retry_count(self, value: u8) -> BuildCommandBuilder<SetRetryCount<S>>where
S::RetryCount: IsUnset,
pub fn retry_count(self, value: u8) -> BuildCommandBuilder<SetRetryCount<S>>where
S::RetryCount: IsUnset,
Sourcepub fn maybe_retry_count(
self,
value: Option<u8>,
) -> BuildCommandBuilder<SetRetryCount<S>>where
S::RetryCount: IsUnset,
pub fn maybe_retry_count(
self,
value: Option<u8>,
) -> BuildCommandBuilder<SetRetryCount<S>>where
S::RetryCount: IsUnset,
Sourcepub fn archive(
self,
value: impl Into<PathBuf>,
) -> BuildCommandBuilder<SetArchive<S>>where
S::Archive: IsUnset,
pub fn archive(
self,
value: impl Into<PathBuf>,
) -> BuildCommandBuilder<SetArchive<S>>where
S::Archive: IsUnset,
Sourcepub fn maybe_archive(
self,
value: Option<impl Into<PathBuf>>,
) -> BuildCommandBuilder<SetArchive<S>>where
S::Archive: IsUnset,
pub fn maybe_archive(
self,
value: Option<impl Into<PathBuf>>,
) -> BuildCommandBuilder<SetArchive<S>>where
S::Archive: IsUnset,
Sourcepub fn registry_namespace(
self,
value: impl Into<String>,
) -> BuildCommandBuilder<SetRegistryNamespace<S>>where
S::RegistryNamespace: IsUnset,
pub fn registry_namespace(
self,
value: impl Into<String>,
) -> BuildCommandBuilder<SetRegistryNamespace<S>>where
S::RegistryNamespace: IsUnset,
Sourcepub fn maybe_registry_namespace(
self,
value: Option<impl Into<String>>,
) -> BuildCommandBuilder<SetRegistryNamespace<S>>where
S::RegistryNamespace: IsUnset,
pub fn maybe_registry_namespace(
self,
value: Option<impl Into<String>>,
) -> BuildCommandBuilder<SetRegistryNamespace<S>>where
S::RegistryNamespace: IsUnset,
Sourcepub fn no_sign(self, value: bool) -> BuildCommandBuilder<SetNoSign<S>>where
S::NoSign: IsUnset,
pub fn no_sign(self, value: bool) -> BuildCommandBuilder<SetNoSign<S>>where
S::NoSign: IsUnset,
Sourcepub fn maybe_no_sign(
self,
value: Option<bool>,
) -> BuildCommandBuilder<SetNoSign<S>>where
S::NoSign: IsUnset,
pub fn maybe_no_sign(
self,
value: Option<bool>,
) -> BuildCommandBuilder<SetNoSign<S>>where
S::NoSign: IsUnset,
Sourcepub fn squash(self, value: bool) -> BuildCommandBuilder<SetSquash<S>>where
S::Squash: IsUnset,
pub fn squash(self, value: bool) -> BuildCommandBuilder<SetSquash<S>>where
S::Squash: IsUnset,
Sourcepub fn maybe_squash(
self,
value: Option<bool>,
) -> BuildCommandBuilder<SetSquash<S>>where
S::Squash: IsUnset,
pub fn maybe_squash(
self,
value: Option<bool>,
) -> BuildCommandBuilder<SetSquash<S>>where
S::Squash: IsUnset,
Sourcepub fn build_chunked_oci(
self,
value: bool,
) -> BuildCommandBuilder<SetBuildChunkedOci<S>>where
S::BuildChunkedOci: IsUnset,
pub fn build_chunked_oci(
self,
value: bool,
) -> BuildCommandBuilder<SetBuildChunkedOci<S>>where
S::BuildChunkedOci: IsUnset,
Sourcepub fn maybe_build_chunked_oci(
self,
value: Option<bool>,
) -> BuildCommandBuilder<SetBuildChunkedOci<S>>where
S::BuildChunkedOci: IsUnset,
pub fn maybe_build_chunked_oci(
self,
value: Option<bool>,
) -> BuildCommandBuilder<SetBuildChunkedOci<S>>where
S::BuildChunkedOci: IsUnset,
Sourcepub fn max_layers(
self,
value: NonZeroU32,
) -> BuildCommandBuilder<SetMaxLayers<S>>where
S::MaxLayers: IsUnset,
pub fn max_layers(
self,
value: NonZeroU32,
) -> BuildCommandBuilder<SetMaxLayers<S>>where
S::MaxLayers: IsUnset,
Sourcepub fn maybe_max_layers(
self,
value: Option<NonZeroU32>,
) -> BuildCommandBuilder<SetMaxLayers<S>>where
S::MaxLayers: IsUnset,
pub fn maybe_max_layers(
self,
value: Option<NonZeroU32>,
) -> BuildCommandBuilder<SetMaxLayers<S>>where
S::MaxLayers: IsUnset,
Sourcepub fn remove_base_image(
self,
value: bool,
) -> BuildCommandBuilder<SetRemoveBaseImage<S>>where
S::RemoveBaseImage: IsUnset,
pub fn remove_base_image(
self,
value: bool,
) -> BuildCommandBuilder<SetRemoveBaseImage<S>>where
S::RemoveBaseImage: IsUnset,
Sourcepub fn maybe_remove_base_image(
self,
value: Option<bool>,
) -> BuildCommandBuilder<SetRemoveBaseImage<S>>where
S::RemoveBaseImage: IsUnset,
pub fn maybe_remove_base_image(
self,
value: Option<bool>,
) -> BuildCommandBuilder<SetRemoveBaseImage<S>>where
S::RemoveBaseImage: IsUnset,
Sourcepub fn rechunk(self, value: bool) -> BuildCommandBuilder<SetRechunk<S>>where
S::Rechunk: IsUnset,
pub fn rechunk(self, value: bool) -> BuildCommandBuilder<SetRechunk<S>>where
S::Rechunk: IsUnset,
Optional (Some / Option setters).
Default: false.
Uses hhd-dev/rechunk to rechunk the image, allowing for smaller images
and smaller updates.
WARN: This will be deprecated in the future.
WARN: This will increase the build-time and take up more space during build-time.
NOTE: This must be run as root!
Sourcepub fn maybe_rechunk(
self,
value: Option<bool>,
) -> BuildCommandBuilder<SetRechunk<S>>where
S::Rechunk: IsUnset,
pub fn maybe_rechunk(
self,
value: Option<bool>,
) -> BuildCommandBuilder<SetRechunk<S>>where
S::Rechunk: IsUnset,
Optional (Some / Option setters).
Default: false.
Uses hhd-dev/rechunk to rechunk the image, allowing for smaller images
and smaller updates.
WARN: This will be deprecated in the future.
WARN: This will increase the build-time and take up more space during build-time.
NOTE: This must be run as root!
Sourcepub fn rechunk_clear_plan(
self,
value: bool,
) -> BuildCommandBuilder<SetRechunkClearPlan<S>>where
S::RechunkClearPlan: IsUnset,
pub fn rechunk_clear_plan(
self,
value: bool,
) -> BuildCommandBuilder<SetRechunkClearPlan<S>>where
S::RechunkClearPlan: IsUnset,
Sourcepub fn maybe_rechunk_clear_plan(
self,
value: Option<bool>,
) -> BuildCommandBuilder<SetRechunkClearPlan<S>>where
S::RechunkClearPlan: IsUnset,
pub fn maybe_rechunk_clear_plan(
self,
value: Option<bool>,
) -> BuildCommandBuilder<SetRechunkClearPlan<S>>where
S::RechunkClearPlan: IsUnset,
Sourcepub fn tempdir(self, value: PathBuf) -> BuildCommandBuilder<SetTempdir<S>>where
S::Tempdir: IsUnset,
pub fn tempdir(self, value: PathBuf) -> BuildCommandBuilder<SetTempdir<S>>where
S::Tempdir: IsUnset,
Sourcepub fn maybe_tempdir(
self,
value: Option<PathBuf>,
) -> BuildCommandBuilder<SetTempdir<S>>where
S::Tempdir: IsUnset,
pub fn maybe_tempdir(
self,
value: Option<PathBuf>,
) -> BuildCommandBuilder<SetTempdir<S>>where
S::Tempdir: IsUnset,
Sourcepub fn cache_layers(self, value: bool) -> BuildCommandBuilder<SetCacheLayers<S>>where
S::CacheLayers: IsUnset,
pub fn cache_layers(self, value: bool) -> BuildCommandBuilder<SetCacheLayers<S>>where
S::CacheLayers: IsUnset,
Sourcepub fn maybe_cache_layers(
self,
value: Option<bool>,
) -> BuildCommandBuilder<SetCacheLayers<S>>where
S::CacheLayers: IsUnset,
pub fn maybe_cache_layers(
self,
value: Option<bool>,
) -> BuildCommandBuilder<SetCacheLayers<S>>where
S::CacheLayers: IsUnset,
Sourcepub fn skip_validation(
self,
value: bool,
) -> BuildCommandBuilder<SetSkipValidation<S>>where
S::SkipValidation: IsUnset,
pub fn skip_validation(
self,
value: bool,
) -> BuildCommandBuilder<SetSkipValidation<S>>where
S::SkipValidation: IsUnset,
Sourcepub fn maybe_skip_validation(
self,
value: Option<bool>,
) -> BuildCommandBuilder<SetSkipValidation<S>>where
S::SkipValidation: IsUnset,
pub fn maybe_skip_validation(
self,
value: Option<bool>,
) -> BuildCommandBuilder<SetSkipValidation<S>>where
S::SkipValidation: IsUnset,
Sourcepub fn credentials(
self,
value: CredentialsArgs,
) -> BuildCommandBuilder<SetCredentials<S>>where
S::Credentials: IsUnset,
pub fn credentials(
self,
value: CredentialsArgs,
) -> BuildCommandBuilder<SetCredentials<S>>where
S::Credentials: IsUnset,
Sourcepub fn maybe_credentials(
self,
value: Option<CredentialsArgs>,
) -> BuildCommandBuilder<SetCredentials<S>>where
S::Credentials: IsUnset,
pub fn maybe_credentials(
self,
value: Option<CredentialsArgs>,
) -> BuildCommandBuilder<SetCredentials<S>>where
S::Credentials: IsUnset,
Sourcepub fn drivers(self, value: DriverArgs) -> BuildCommandBuilder<SetDrivers<S>>where
S::Drivers: IsUnset,
pub fn drivers(self, value: DriverArgs) -> BuildCommandBuilder<SetDrivers<S>>where
S::Drivers: IsUnset,
Sourcepub fn maybe_drivers(
self,
value: Option<DriverArgs>,
) -> BuildCommandBuilder<SetDrivers<S>>where
S::Drivers: IsUnset,
pub fn maybe_drivers(
self,
value: Option<DriverArgs>,
) -> BuildCommandBuilder<SetDrivers<S>>where
S::Drivers: IsUnset,